Flask PynamoDB Resource
=======================

Presents PynamoDB models (DynamoDB tables) as Flask-RESTful resources

Consult `README.md on GitHub <https://github.com/brandond/flask-pynamodb-resource/blob/master/README.md>`__ for usage instructions.
